@@ -1,6 +1,7 @@
 #' Find patterns in expressions
 #'
-#' Match and extract patterns in an [expression][elixir-expression] or a list of expressions.
+#' Match and extract patterns in an [expression][elixir-expression] or a list
+#' of expressions.
 #'
 #' @usage
 #' expr_match(expr, pattern, n = Inf,
@@ -13,7 +14,8 @@
 #' expr_locate(expr, pattern, n = Inf, gather = FALSE,
 #'     env = parent.frame())
 #' @param expr Input. An [expression][elixir-expression], [expr_list], or
-#' [list()] of expressions.
+#'     [list()] of expressions. Also works with [formulas][base::tilde] or lists
+#'     of formulas.
 #' @param pattern Pattern to look for. An [expression][elixir-expression], a
 #'     length-one [expr_list], or a length-one [list] of expressions. The
 #'     question mark syntax (see [expression][elixir-expression]) can be used
@@ -223,7 +225,7 @@ expr_match = function(expr, pattern, n = Inf, dotnames = FALSE, env = parent.fra
         stop("expr_match requires one pattern.")
     }
 
-    if (is(pattern[[1]], "expr_alt")) {
+    if (inherits(pattern[[1]], "expr_alt")) {
         into = attr(pattern[[1]], "into")
     } else {
         into = attr(pattern, "into")
@@ -231,7 +233,7 @@ expr_match = function(expr, pattern, n = Inf, dotnames = FALSE, env = parent.fra
 
     # Do matching
     result = lapply(seq_along(expr), function(i) {
-        loc_start = if (is(expr, "expr_wrap")) NULL else i
+        loc_start = if (inherits(expr, "expr_wrap")) NULL else i
         match = match_sub(expr[[i]], pattern[[1]], n, into, dotnames = dotnames, loc_start, NULL, env);
         if (!is.null(match)) {
             return (structure(lapply(match, function(m) m[!names(m) %like% "^_"]), class = "expr_match"))
@@ -240,7 +242,7 @@ expr_match = function(expr, pattern, n = Inf, dotnames = FALSE, env = parent.fra
     });
 
     # Return result
-    if (is(expr, "expr_wrap")) {
+    if (inherits(expr, "expr_wrap")) {
         return (result[[1]])
     } else {
         return (result)
@@ -375,7 +377,7 @@ match_sub = function(expr, pattern, n, into, dotnames, loc, parent_match, env)
     match = NULL;
 
     # Do matching
-    if (is(pattern, "expr_alt")) {
+    if (inherits(pattern, "expr_alt")) {
         # Alternative expressions: try each, get first matching one.
         for (p in seq_along(pattern)) {
             # Skip alternatives marked as not for matching (see 2. below)
@@ -402,7 +404,7 @@ match_sub = function(expr, pattern, n, into, dotnames, loc, parent_match, env)
 
     # 2. Now attempt to match to subcomponents of expr -- i.e. if still looking
     # for matches, and can go into expression, then do so
-    if (is(pattern, "expr_alt")) {
+    if (inherits(pattern, "expr_alt")) {
         # For those alternatives which we should not use for recursion, set
         # "into" to NA to mark that alternative as something we should not try
         # to match to.
